@@ -163,24 +163,29 @@ setMethod("nrow","Dna", function(x)
 
 
 
-#fixing a change in R base, adding drop argument June 2023
+#fixing a change in R base, adding drop argument  July 11, 2023
 
-setMethod("[", "Dna", function(x, i = 1:nrow(x), j = 1:ncol(x), as.matrix = TRUE, drop = FALSE)
-{
-    seq <- x@sequence[i,j,drop=FALSE]
-    lseq <- ncol(seq)
-    seqnames <- x@seqnames[i]
+setMethod("[", "Dna",
+    function(x, i = 1:nrow(x), j = 1:ncol(x), ..., drop=FALSE) {
+        # Default values
+        as.matrix <- TRUE
 
-    if(as.matrix) {
-        if(drop && (nrow(seq) == 1)) {
-            return(as.vector(seq)) # convert to vector if drop is TRUE and seq is a single row/column
+        # Check if as.matrix is supplied in ...
+        args <- list(...)
+        if ("as.matrix" %in% names(args)) {
+            as.matrix <- args[["as.matrix"]]
+        }
+
+        if(as.matrix) {
+                seq <- x@sequence[i,j,drop=drop]
+                return(seq)
+            
         } else {
-            return(seq) 
+            seq <- x@sequence[i,j,drop=FALSE]
+            return(new("Dna", sequence=seq, seqlengths=rep(ncol(seq), nrow(seq)), seqnames=rownames(seq)))
         }
-    } else {
-        new("Dna", sequence=seq, seqlengths=rep(lseq, nrow(seq)), seqnames=seqnames)
     }
-})
+)
 
 
 
